==> aroundme_0_3_3.zip: aroundme_0_3_3/www/aroundme_0_3_3/template/am_default/g_acs.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2004 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>


<form action="g_acs.php" method="post">
<input type="hidden" name="data[role_id]" value="<?php if (isset($role['role_id'])) {echo $role['role_id'];}?>" />
<input type="hidden" name="group_id" value="<?php echo $group['group_id'];?>" />

<table width="770" cellpadding="0" cellspacing="0" border="0">
	<tr>
		<td width="180" valign="top">
			<?php
			include $templatePath . "g_menu.inc.tpl.php";
			?>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="52" alt="" /><br />

			<?php
			include $templatePath . "logo.inc.tpl.php";
			?>
		</td>

		<td width="20">&nbsp;</td>

		<td width="570" valign="top">
			<table cellpadding="4" cellspacing="0" border="0" width="100%">
				<tr>
					<td class="txt_title" align="right">
						<?php echo $lang['hdr_acs_permissions'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td valign="top" class="txt_footer">
						<?php echo $lang['txt_acs_permissions_help'];?><br />
					</td>
				</tr>
			</table>
			
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="4" alt="" /><br />

			<table cellpadding="4" cellspacing="0" border="0" width="100%" class="picture">
				<tr>
					<td class="bg1">
						<?php echo $lang['txt_acs_role_number'];?><br />
					</td>
					<?php
					//create the table header with the roles
					if (isset($roles[0])) {
					foreach($roles as $key => $rol):
					?>
					<td class="bg1" align="center">
						<?php echo $key+1;?><br />
					</td>
					<?php
					endforeach;
					}
					?>
				</tr>
				<?php
				if (isset($resources[0])) {
				foreach($resources as $key1 => $res):
				?>
				<tr>
					<td class="bg2">
						<?php echo $res['resource_name'];?><br />
					</td>
					<td colspan="<?php echo count($roles);?>" class="bg2">
						<?php echo $res['resource_desc'];?><br />
					</td>
				</tr>
					<?php
					//get the privileges for each resource
					if (isset($res['privileges'])) {
					foreach($res['privileges'] as $key2 => $priv):
					?>
					<tr>
						<td>
							<?php echo $priv['privilege_name'];?><br />
						</td>
							<?php
							//create a table for each permission (one per role)
							if (isset($priv['permissions'])) {
							foreach($priv['permissions'] as $key3 => $perm):
							$checked = "";
							if ($perm == 1) {
							    $checked = "checked";
							}
							?>
							<td align="center">
								<input type="checkbox" name="data[ids]" value="1" <?php echo $checked;?> /><br />
							</td>
							<?php
							endforeach;
							}
							?>
					</tr>
					<?php
					endforeach;
					}
					?>
				
				<?php
				endforeach;
				}
				?>
			</table>
			<table cellpadding="4" cellspacing="0" border="0" width="100%">
				<tr>
					<td align="right" valign="top">
						<input type="submit" name="update_permissions" value="<?php echo $lang['sub_update_permissions'];?>" class="formInput" / ><br />
					</td>
				</tr>
			</table>
			
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />
			
			<table cellpadding="4" cellspacing="0" border="0" width="100%">
				<tr>
					<td class="txt_title" align="right">
						<?php echo $lang['hdr_acs_roles'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td valign="top" class="txt_footer">
						<?php echo $lang['txt_acs_roles_help'];?><br />
					</td>
				</tr>
				<?php
				if (isset($roles[0])) {
				foreach($roles as $key => $i):
				?>
				<tr>
					<td valign="top">
						<?php echo ($key+1);?>:&nbsp;<a href="g_acs.php?group_id=<?php echo $group['group_id'];?>&amp;role_id=<?php echo $i['role_id'];?>"><?php echo $i['role_name'];?></a><br />
					</td>
				</tr>
				<?php
				endforeach;
				}
				?>
			</table>
			
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />
			
			<table cellpadding="4" cellspacing="0" border="0" width="100%">
				<tr>
					<td class="txt_title" align="right" colspan="2">
						<?php echo $lang['hdr_acs_role'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td valign="top" class="txt_footer" colspan="2">
						<?php echo $lang['txt_acs_role_help'];?><br />
					</td>
				</tr>
				<tr>
					<td valign="top" colspan="2">
						<?php echo $lang['txt_name'];?><br />
					</td>
				</tr>
				<tr>
					<td valign="top" colspan="2">
						<input type="text" size="35" name="data[role_name]" value="<?php if (isset($role['role_name'])) {echo $role['role_name'];}?>" class="formInput" /><br />
					</td>
				</tr>
				<tr>
					<td colspan="2">
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="4" alt="" /><br />
					</td>
				</tr>
				<?php
				if (isset($role)) {
				?>
				<tr>
					<td>
						<input type="submit" name="delete_role" value="<?php echo $lang['sub_delete_role'];?>" class="formInput" /><br />
					</td>
					<td align="right">
						<input type="submit" name="update_role" value="<?php echo $lang['sub_update_role'];?>" class="formInput" /><br />
					</td>
				</tr>
				<?php
				}
				else {
				?>
				<tr>
					<td align="right" colspan="2">
						<input type="submit" name="insert_role" value="<?php echo $lang['sub_insert_role'];?>" class="formInput" /><br />
					</td>
				</tr>
				<?php
				}
				?>
			</table>
		</td>
	</tr>
</table>
</form>

==> aroundme-0_4_0.zip: aroundme_0_4_0/www/aroundme_0_4_0/template/am_default/g_acs.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>


<form action="g_acs.php" method="post">
<input type="hidden" name="data[role_id]" value="<?php if (isset($role['role_id'])) {echo $role['role_id'];}?>" />
<input type="hidden" name="group_id" value="<?php echo $group['group_id'];?>" />

<table width="770" cellpadding="0" cellspacing="0" border="0">
	<tr>
		<td width="180" valign="top">
			<?php
			include $templatePath . "g_menu.inc.tpl.php";
			?>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="52" alt="" /><br />

			<?php
			include $templatePath . "logo.inc.tpl.php";
			?>
		</td>

		<td width="20">&nbsp;</td>

		<td width="570" valign="top">
			<table cellpadding="4" cellspacing="0" border="0" width="100%">
				<tr>
					<td class="txt_title" align="right">
						<?php echo $lang['hdr_acs_permissions'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td valign="top" class="txt_footer">
						<?php echo $lang['txt_acs_permissions_help'];?><br />
					</td>
				</tr>
			</table>
			
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="4" alt="" /><br />

			<table cellpadding="4" cellspacing="0" border="0" width="100%" class="picture">
				<tr>
					<td class="bg1">
						<?php echo $lang['txt_acs_role_number'];?><br />
					</td>
					<?php
					//create the table header with the roles
					if (isset($roles)) {
					foreach($roles as $key => $rol):
					?>
					<td class="bg1" align="center">
						<?php echo $key+1;?><br />
					</td>
					<?php
					endforeach;
					}
					?>
				</tr>
				<?php
				if (isset($resources[0])) {
				foreach($resources as $key1 => $res):
				?>
				<tr>
					<td class="bg2">
						<?php echo $res['resource_name'];?><br />
					</td>
					<td colspan="<?php echo count($roles);?>" class="bg2">
						<?php echo $res['resource_desc'];?><br />
					</td>
				</tr>
					<?php
					//get the privileges for each resource
					if (isset($res['privileges'])) {
					foreach($res['privileges'] as $key2 => $priv):
					?>
					<tr>
						<td>
							<?php echo $priv['privilege_name'];?><br />
						</td>
							<?php
							//create a table for each permission (one per role)
							if (isset($priv['permissions'])) {
							foreach($priv['permissions'] as $key3 => $perm):
							$checked = "";
							if ($perm == 1) {
							    $checked = "checked";
							}
							?>
							<td align="center">
								<input type="checkbox" name="data[ids][<?php echo $res["resource_id"]."-".$priv["privilege_id"]."-".$key3;?>]" value="1" <?php echo $checked;?> /><br />
							</td>
							<?php
							endforeach;
							}
							?>
					</tr>
					<?php
					endforeach;
					}
					?>
				
				<?php
				endforeach;
				}
				?>
			</table>
			<table cellpadding="4" cellspacing="0" border="0" width="100%">
				<tr>
					<td align="right" valign="top">
						<input type="submit" name="update_permissions" value="<?php echo $lang['sub_update_permissions'];?>" class="formInput" / ><br />
					</td>
				</tr>
			</table>
			
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />
			
			<table cellpadding="4" cellspacing="0" border="0" width="100%">
				<tr>
					<td class="txt_title" align="right" colspan="2">
						<?php echo $lang['hdr_acs_roles'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td valign="top" class="txt_footer" colspan="2">
						<?php echo $lang['txt_acs_roles_help'];?><br />
					</td>
				</tr>
				<tr>
					<td valign="top">
						<b><?php echo $lang['txt_role_name'];?></b><br />
					</td>
					<td valign = "top" align="right">
						<b><?php echo $lang['txt_default_role'];?></b><br />
					</td>
				</tr>
				<?php
				if (isset($roles[0])) {
				foreach($roles as $key => $i):
				?>
				<tr>
					<td valign="top">
						<?php echo ($key+1);?>:&nbsp;<a href="g_acs.php?group_id=<?php echo $group['group_id'];?>&amp;role_id=<?php echo $i['role_id'];?>"><?php echo $i['role_name'];?></a><br />
					</td>
					<td valign = "top" align="right">
						<?php
						$selected = "";
						if ($i['role_default'] == 1) {
						    $selected = "checked=\nchecked\n";
						}
						?>
						<input type="radio" name="data[default_role_id]" value="<?php echo $i['role_id'];?>" <?php echo $selected;?> /><br />
					</td>
				</tr>
				<?php
				endforeach;
				}
				?>
				<tr>
					<td align="right" colspan="2">
						<input type="submit" name="set_default" value="<?php echo $lang['sub_update_default_role'];?>" class="formInput" /><br />
					</td>
				</tr>
			</table>
			
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />
			
			<table cellpadding="4" cellspacing="0" border="0" width="100%">
				<tr>
					<td class="txt_title" align="right" colspan="2">
						<?php echo $lang['hdr_acs_role'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td valign="top" class="txt_footer" colspan="2">
						<?php echo $lang['txt_acs_role_help'];?><br />
					</td>
				</tr>
				<tr>
					<td valign="top" colspan="2">
						<?php echo $lang['txt_name'];?><br />
					</td>
				</tr>
				<tr>
					<td valign="top" colspan="2">
						<input type="text" size="35" name="data[role_name]" value="<?php if (isset($role['role_name'])) {echo $role['role_name'];}?>" class="formInput" /><br />
					</td>
				</tr>
				<tr>
					<td colspan="2">
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="4" alt="" /><br />
					</td>
				</tr>
				<?php
				if (isset($role)) {
				?>
				<tr>
					<td>
						<input type="hidden" name="data[role_default]" value="<?php if (isset($role['role_default'])) {echo 1;}?>" />
						<input type="submit" name="delete_role" value="<?php echo $lang['sub_delete_role'];?>" class="formInput" /><br />
					</td>
					<td align="right">
						<input type="submit" name="update_role" value="<?php echo $lang['sub_update_role'];?>" class="formInput" /><br />
					</td>
				</tr>
				<?php
				}
				else {
				?>
				<tr>
					<td align="right" colspan="2">
						<input type="submit" name="insert_role" value="<?php echo $lang['sub_insert_role'];?>" class="formInput" /><br />
					</td>
				</tr>
				<?php
				}
				?>
			</table>
		</td>
	</tr>
</table>
</form>
